Page 133 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 133

Home

    man who had written in his will that, "I have at all times
    considered myself a disciple of Jesus Christ," went to

    Sad

    see his Master. After a beautiful sunny day on April 5, at
    midnight, just minutes after Chiang's passing, a terrible
    storm of rain, thunder, and lightning raged over the island
    causing sleepy Chinese everywhere to rise from their
    beds and gaze upon the storm. Whether this was chance
    or providence, no one knows.

    The tragedy of the China story is that the most
    populous : nation on earth, a 1 nation that could have been

    corm

    one of the world's greatest examples of Christian
    leadership, was betrayed by the one nation that the world
    would least suspect, the United States of America. As
    has been stated by others who have commented upon this
    horrible betrayal, "May God forgive us!"

    Cuba is another example of a land where God was

    banned. It is also an example of yet another country
    betrayed into Communist slavery by American hands. It
    would have been impossible for a known Communist
    terrorist (Castro) and his band of 83 men, holed up in the
    Sierra Maestra Mountains, to take over Cuba without
    powerful outside help. Where this powerful help came
    from was related by former United States Ambassador to
    Cuba, Earl E. T. Smith in his book The Fourth Floor: An

    served as ambassador during the time of Castro's rise to
    power (1957-58) and had first hand knowledge of these

    events.

    128

    The Secret Side of History

    Account of the Castro Communist Revolution. Smith